@@ -18,7 +18,11 @@ def _cast_or_none(func, value):
         return None
 
 
-load_dotenv()
+try:
+    load_dotenv()
+except EnvironmentError:
+    # XXX: Workaround for readthedocs  # pylint: disable=fixme
+    pass
 
 # Ground station information
 SATNOGS_API_TOKEN = environ.get('SATNOGS_API_TOKEN', None)
@@ -28,7 +32,10 @@ SATNOGS_STATION_ID = _cast_or_none(int, environ.get('SATNOGS_STATION_ID', None))
 SATNOGS_STATION_LAT = _cast_or_none(float, environ.get('SATNOGS_STATION_LAT', None))
 SATNOGS_STATION_LON = _cast_or_none(float, environ.get('SATNOGS_STATION_LON', None))
 SATNOGS_STATION_ELEV = _cast_or_none(int, environ.get('SATNOGS_STATION_ELEV', None))
-GPSD_ENABLED = bool(strtobool(environ.get('GPSD_ENABLED', 'False')))
+SATNOGS_GPSD_CLIENT_ENABLED = bool(strtobool(environ.get('SATNOGS_GPSD_CLIENT_ENABLED', 'False')))
+SATNOGS_GPSD_HOST = environ.get('SATNOGS_GPSD_HOST', "127.0.0.1")
+SATNOGS_GPSD_PORT = _cast_or_none(int, environ.get('SATNOGS_GPSD_PORT', 2947))
+SATNOGS_GPSD_TIMEOUT = _cast_or_none(int, environ.get('SATNOGS_GPSD_TIMEOUT', 0))
 
 # Output paths
 SATNOGS_APP_PATH = environ.get('SATNOGS_APP_PATH', '/tmp/.satnogs')
@@ -67,8 +74,8 @@ GNURADIO_AFSK_SALSAT_SCRIPT_FILENAME = 'satnogs_afsk_salsat.py'
 GNURADIO_AFSK_SNET_SCRIPT_FILENAME = 'satnogs_afsk_snet.py'
 GNURADIO_AMSAT_DUV_SCRIPT_FILENAME = 'satnogs_amsat_fox_duv_decoder.py'
 GNURADIO_SSTV_SCRIPT_FILENAME = 'satnogs_sstv_pd120_demod.py'
+GNURADIO_ARGOS_BPSK_PMT_A3 = 'satnogs_argos_bpsk_ldr.py'
 
-SATNOGS_ROT_IP = environ.get('SATNOGS_ROT_IP', '127.0.0.1')
 SATNOGS_ROT_MODEL = environ.get('SATNOGS_ROT_MODEL', 'ROT_MODEL_DUMMY')
 SATNOGS_ROT_BAUD = int(environ.get('SATNOGS_ROT_BAUD', 19200))
 SATNOGS_ROT_PORT = environ.get('SATNOGS_ROT_PORT', '/dev/ttyUSB0')
@@ -84,34 +91,38 @@ SATNOGS_RX_SAMP_RATE = environ.get('SATNOGS_RX_SAMP_RATE', None)
 SATNOGS_RX_BANDWIDTH = environ.get('SATNOGS_RX_BANDWIDTH', None)
 SATNOGS_DOPPLER_CORR_PER_SEC = environ.get('SATNOGS_DOPPLER_CORR_PER_SEC', None)
 SATNOGS_LO_OFFSET = environ.get('SATNOGS_LO_OFFSET', None)
+SATNOGS_PPM_ERROR = environ.get('SATNOGS_PPM_ERROR', None)
+SATNOGS_GAIN_MODE = environ.get('SATNOGS_GAIN_MODE', 'Overall')
 SATNOGS_RF_GAIN = environ.get('SATNOGS_RF_GAIN', None)
 SATNOGS_ANTENNA = environ.get('SATNOGS_ANTENNA', None)
 SATNOGS_DEV_ARGS = environ.get('SATNOGS_DEV_ARGS', None)
+SATNOGS_STREAM_ARGS = environ.get('SATNOGS_STREAM_ARGS', None)
+SATNOGS_TUNE_ARGS = environ.get('SATNOGS_TUNE_ARGS', None)
+SATNOGS_OTHER_SETTINGS = environ.get('SATNOGS_OTHER_SETTINGS', None)
+SATNOGS_DC_REMOVAL = environ.get('SATNOGS_DC_REMOVAL', None)
+SATNOGS_BB_FREQ = environ.get('SATNOGS_BB_FREQ', None)
+
 ENABLE_IQ_DUMP = bool(strtobool(environ.get('ENABLE_IQ_DUMP', 'False')))
 IQ_DUMP_FILENAME = environ.get('IQ_DUMP_FILENAME', None)
 DISABLE_DECODED_DATA = bool(strtobool(environ.get('DISABLE_DECODED_DATA', 'False')))
 
 # Waterfall settings
-SATNOGS_WATERFALL_AUTORANGE = environ.get('SATNOGS_WATERFALL_AUTORANGE', True)
-SATNOGS_WATERFALL_MIN_VALUE = environ.get('SATNOGS_WATERFALL_MIN_VALUE', -100)
-SATNOGS_WATERFALL_MAX_VALUE = environ.get('SATNOGS_WATERFALL_MAX_VALUE', -50)
+SATNOGS_WATERFALL_AUTORANGE = bool(strtobool(environ.get('SATNOGS_WATERFALL_AUTORANGE', 'True')))
+SATNOGS_WATERFALL_MIN_VALUE = int(environ.get('SATNOGS_WATERFALL_MIN_VALUE', -100))
+SATNOGS_WATERFALL_MAX_VALUE = int(environ.get('SATNOGS_WATERFALL_MAX_VALUE', -50))
 
 # Logging configuration
-LOG_FORMAT = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+LOG_FORMAT = '%(name)s - %(levelname)s - %(message)s'
 LOG_LEVEL = environ.get('SATNOGS_LOG_LEVEL', 'WARNING')
 SCHEDULER_LOG_LEVEL = environ.get('SATNOGS_SCHEDULER_LOG_LEVEL', 'WARNING')
 
 # Sentry
-SENTRY_DSN = environ.get('SENTRY_DSN', '')
+SENTRY_DSN = environ.get('SENTRY_DSN', 'd50342fb75aa8f3945e2f846b77a0cdb7c7d2275')
+SENTRY_ENABLED = bool(strtobool(environ.get('SENTRY_ENABLED', 'False')))
 
 REQUIRED_VARIABLES = [
-    'SATNOGS_API_TOKEN',
-    'SATNOGS_STATION_ID',
-    'SATNOGS_STATION_LAT',
-    'SATNOGS_STATION_LON',
-    'SATNOGS_STATION_ELEV',
-    'SATNOGS_SOAPY_RX_DEVICE',
-    'SATNOGS_RX_SAMP_RATE',
+    'SATNOGS_API_TOKEN', 'SATNOGS_STATION_ID', 'SATNOGS_STATION_LAT', 'SATNOGS_STATION_LON',
+    'SATNOGS_STATION_ELEV', 'SATNOGS_SOAPY_RX_DEVICE', 'SATNOGS_RX_SAMP_RATE', 'SATNOGS_ANTENNA'
 ]
 
 
@@ -144,15 +155,15 @@ def validate(logger):
         logger.error('Invalid SATNOGS_NETWORK_API_URL: %s', SATNOGS_NETWORK_API_URL)
         settings_valid = False
 
-    if not (SATNOGS_STATION_LAT or GPSD_ENABLED):
+    if not (SATNOGS_STATION_LAT or SATNOGS_GPSD_CLIENT_ENABLED):
         logger.error('SATNOGS_STATION_LAT not configured')
         settings_valid = False
 
-    if not (SATNOGS_STATION_LON or GPSD_ENABLED):
+    if not (SATNOGS_STATION_LON or SATNOGS_GPSD_CLIENT_ENABLED):
         logger.error('SATNOGS_STATION_LON not configured')
         settings_valid = False
 
-    if SATNOGS_STATION_ELEV is None and GPSD_ENABLED is False:
+    if SATNOGS_STATION_ELEV is None and SATNOGS_GPSD_CLIENT_ENABLED is False:
         logger.error('SATNOGS_STATION_ELEV not configured')
         settings_valid = False
 
